@@ -337,7 +337,7 @@ impl<'a> Iterator for RowIter<'a> {
                     Ok(Event::Text(ref e)) if in_value => {
                         c.raw_value = e.unescape_and_decode(&reader).unwrap();
                         c.value = match &c.cell_type[..] {
-                            "s" | "str" => {
+                            "s" => {
                                 if let Ok(pos) = c.raw_value.parse::<usize>() {
                                     let s = &strings[pos]; // .to_string()
                                     ExcelValue::String(Cow::Borrowed(s))
@@ -345,6 +345,9 @@ impl<'a> Iterator for RowIter<'a> {
                                     ExcelValue::String(Cow::Owned(c.raw_value.clone()))
                                 }
                             },
+                            "str" => {
+                                ExcelValue::String(Cow::Owned(c.raw_value.clone()))
+                            },
                             "b" => {
                                 if c.raw_value == "0" {
                                     ExcelValue::Bool(false)
